@@ -52,23 +52,23 @@ def _touch(fname):
 def _build(assets, pwd):
     for child in assets:
         if (type(assets[child]) is str):
-            _touch(pwd + '/' + assets[child])
+            _touch(pwd + os.sep + assets[child])
         else:
             if not os.path.exists(child):
-                os.makedirs(pwd + '/' + child)
-            _build(assets[child], pwd + '/' + child)
+                os.makedirs(pwd + os.sep + child)
+            _build(assets[child], pwd + os.sep + child)
 
 
 def generate_assets(dir):
-    if not os.path.exists(dir+'/assets'):
-        os.makedirs(dir+'/assets')
-    _build(_assets, dir+'/assets')
-    #setup angular application
+    if not os.path.exists(dir + os.sep + 'assets'):
+        os.makedirs(dir + os.sep + 'assets')
+    _build(_assets, dir + os.sep + 'assets')
+    # setup angular application
     app_name = raw_input("Angular Application Name: ")
-    with open(dir + '/assets/app/app.js','w') as app:
+    with open(dir + os.sep + 'assets' + os.sep + 'app' + os.sep + 'app.js', 'w') as app:
         app.write('var app = angular.module("%s", []);' % app_name)
-    #setup styles
-    with open(dir + '/assets/lib/styles/styles.scss', 'w') as styles:
+    # setup styles
+    with open(dir + os.sep + 'assets' + os.sep + 'lib' + os.sep + 'styles' + os.sep + 'styles.scss', 'w') as styles:
         styles.write('//setup\n'
                      '@import "site/variables";\n'
                      '@import "site/mixins";\n'
